# geodemo

[![image](https://img.shields.io/pypi/v/geodemo.svg)](https://pypi.python.org/pypi/geodemo)
[![image](https://img.shields.io/conda/vn/conda-forge/geodemo.svg)](https://anaconda.org/conda-forge/geodemo)
[![image](https://pepy.tech/badge/geodemo)](https://pepy.tech/project/geodemo)
[![image](https://github.com/giswqs/geodemo/workflows/docs/badge.svg)](https://geodemo.gishub.org)
[![image](https://github.com/giswqs/geodemo/workflows/build/badge.svg)](https://github.com/giswqs/geodemo/actions?query=workflow%3Abuild)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**A Python package for interactive mapping**


-   Free software: MIT license
-   Documentation: https://giswqs.github.io/geodemo
    

## Features

-   TODO
-   TODO 2

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
